<div align="center">

# 孤寡机器人,让你的孤寡朋友露出阳光的笑容

</div>

## 使用方式

- 先创建群聊，可以起一个好听一点的名字例如

![avatar](/图/名字.png)

- 然后把你的机器人拉进来，并给一个管理

![avatar](/图/拉人.png)

- 最后,邀请受害人加入本群即可(小于 50 不需要同意哦！)

![avatar](/图/被迫害.jpg)
